@@ -17,6 +17,7 @@ from polly.errors import (
     OperationFailedException,
     paramException,
     AccessDeniedError,
+    InvalidRepoException,
 )
 from polly.constants import COHORT_CONSTANTS_URL, REPORT_FIELDS_URL, ELUCIDATA_LOGO_URL
 from bs4 import BeautifulSoup
@@ -493,3 +494,18 @@ def verify_workspace_details(self, workspace_id, workspace_path, sts_url) -> Non
             title="Param Error",
             detail="The given workspace path does not represent a file. Please try again.",
         )
+
+
+def return_entity_type(data_source: str, cohort_info: json) -> str:
+    """
+    Function to return entity type based on the cohort info present in public assets
+    """
+    if data_source not in cohort_info:
+        raise InvalidRepoException(data_source)
+    for repo, dict in cohort_info.items():
+        if data_source == repo:
+            if dict["file_structure"] == "single":
+                entity_type = "dataset"
+            elif dict["file_structure"] == "multiple":
+                entity_type = "sample"
+    return entity_type
